import os
import yaml
from pathlib import Path

def set_env_variables_from_dict(data):
    for key, value in data.items():
        os.environ[key] = str(value)

def set_env_variables_from_yaml(yaml_path):
    with open(yaml_path, 'r') as file:
        configs = yaml.safe_load(file)

    selenium_config = configs.get('selenium-configuration', {})
    set_env_variables_from_dict(selenium_config)

    # Handle credentials
    creds_file_path = configs.get('test-credentials', {}).get('file')
    if creds_file_path and Path(creds_file_path).exists():
        with open(creds_file_path, 'r') as creds_file:
            credentials = yaml.safe_load(creds_file)
        set_env_variables_from_dict(credentials)
    else:
        print(f"Credentials file '{creds_file_path}' not found.")

CONFIG_YAML_FILE = 'vgl_config.yaml'

if Path(CONFIG_YAML_FILE).exists():
    print(f"Setting configuration from {CONFIG_YAML_FILE} file.")
    set_env_variables_from_yaml(CONFIG_YAML_FILE)
else:
    print(f"Could not find `{CONFIG_YAML_FILE}` configuration file.")
    print("If you don't want to use the yaml configuration file, ensure you provide all configuration data as environment variables.")



#!/usr/bin/env python

import click
from .install_webdriver_command import install_webdriver
from .install_standalone_command import install_selenium_standalone
from .install_dev_kit_command import install_dev_kit

from .selenium_commands import run_selenium_server, stop_selenium_server


@click.group(name="vgl.py")
def vgl():
    pass


vgl.add_command(run_selenium_server)
vgl.add_command(stop_selenium_server)


vgl.add_command(install_webdriver)
vgl.add_command(install_selenium_standalone)
vgl.add_command(install_dev_kit)


if __name__ == '__main__':
    vgl()



import subprocess
import click
import psutil

SELENIUM_SERVER_JAR = "selenium-server/selenium-server-standalone.jar"


def find_selenium_server_process():
    for process in psutil.process_iter(['pid', 'name', 'cmdline']):
        if process.info['name'] == 'java' and SELENIUM_SERVER_JAR in process.info['cmdline']:
            return process
    return None


@click.command(name='server:run', help="Run Selenium Server JAR file")
@click.option('--port', '-p', type=int, default=4444, help="Port number for the server")
@click.option('--driver', '-D', multiple=True,
              help="Specify driver options (e.g. -Dwebdriver.chrome.driver=chromedriver)")
@click.option('--daemon', '-d', is_flag=True, help="Run the server as a daemon")
def run_selenium_server(port, driver, daemon):
    driver_options = " ".join(driver)
    cmd = ["java", "-jar", SELENIUM_SERVER_JAR, "-port", str(port)]
    cmd.extend(driver_options.split())

    click.echo(f"Running Selenium Server with command:\n {' '.join(cmd)}")

    if daemon:
        # Start the process in the background (daemon mode) using subprocess.Popen
        process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=False)
        click.echo(f"Selenium Server is running in daemon mode with PID: {process.pid}")
    else:
        # Start the process in the foreground and wait for it to finish using subprocess.run
        subprocess.run(cmd)


@click.command(name='server:stop', help="Stop the running Selenium Server")
def stop_selenium_server():
    selenium_server_process = find_selenium_server_process()
    if selenium_server_process:
        pid = selenium_server_process.info['pid']
        try:
            selenium_server_process.terminate()
            click.echo(f"Selenium Server with PID {pid} has been stopped.")
        except psutil.NoSuchProcess:
            click.echo(f"Failed to stop Selenium Server. Process with PID {pid} does not exist.")
    else:
        click.echo("Selenium Server is not running in daemon mode.")
